==> 1.1.0.tar.gz: lxqt-config-1.1.0/lxqt-config-brightness/translations/lxqt-config-brightness_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>Helligkeitseinstellungen</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="35"/>
        <location filename="../brightnesssettings.ui" line="74"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Hintergrundbeleuchtungs- und Helligkeitseinstellungen:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="51"/>
        <source>Backlight</source>
        <translation>Hintergrundbeleuchtung</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="57"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="87"/>
        <source>Brightness</source>
        <translation>Helligkeit</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="105"/>
        <source>Require confirmation after settings change</source>
        <translation>Bestätigung nach Änderung der Einstellungen erforderlich</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="112"/>
        <source>Brightness settings changed</source>
        <translation>Helligkeitseinstellungen geändert</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="113"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>Bestätigung erforderlich. Sind diese Einstellungen korrekt?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ausgabe:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="48"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="80"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Increase brightness.</source>
        <translation>Helligkeit erhöhen.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Decrease brightness.</source>
        <translation>Helligkeit verringern.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Set brightness from 1 to 100.</source>
        <translation>Helligkeit von 1 bis 100 einstellen.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Reset gamma to default value.</source>
        <translation>Gamma auf Standardwert zurücksetzen.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="112"/>
        <source>%1: Can&apos;t use increase/decrease and set in conjunction</source>
        <translation>%1: Erhöhen/Verringern und Festlegen können nicht zusammen verwendet werden</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>%1: Can&apos;t use increase and decrease options in conjunction</source>
        <translation>%1: Optionen zum Erhöhen und Verringern können nicht zusammen verwendet werden</translation>
    </message>
</context>
</TS>

==> 2.1.0.tar.gz: lxqt-config-2.1.0/lxqt-config-brightness/translations/lxqt-config-brightness_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>Helligkeitseinstellungen</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="35"/>
        <location filename="../brightnesssettings.ui" line="74"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Hintergrundbeleuchtungs- und Helligkeitseinstellungen:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="51"/>
        <source>Backlight</source>
        <translation>Hintergrundbeleuchtung</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="57"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="87"/>
        <source>Brightness</source>
        <translation>Helligkeit</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="105"/>
        <source>Require confirmation after settings change</source>
        <translation>Bestätigung nach Änderung der Einstellungen erforderlich</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="112"/>
        <source>Brightness settings changed</source>
        <translation>Helligkeitseinstellungen geändert</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="113"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>Bestätigung erforderlich. Sind diese Einstellungen korrekt?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ausgabe:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="48"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="80"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Increase brightness.</source>
        <translation>Helligkeit erhöhen.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Decrease brightness.</source>
        <translation>Helligkeit verringern.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Set brightness from 1 to 100.</source>
        <translation>Helligkeit ändern von 1 bis 100.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Reset gamma to default value.</source>
        <translation>Setze gamma auf Standardwert.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="112"/>
        <source>%1: Can&apos;t use increase/decrease and set in conjunction</source>
        <translation>%1: Erhöhen/Verringern und Festlegen können nicht zusammen verwendet werden</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>%1: Can&apos;t use increase and decrease options in conjunction</source>
        <translation>%1: Optionen zum Erhöhen und Verringern können nicht zusammen verwendet werden</translation>
    </message>
</context>
</TS>
